@@ -157,9 +157,8 @@ def volume_weighted_high_low_vol(data = None, vol_threshold = 0.8, up_trend_thre
     data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
     data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
 
-    trend_rank = data['close_ret_pct_rank'][-1]
-    vol_rank = data['volu_hi_low_pct_rank'][-1]
-
+    trend_rank = data['close_ret_pct_rank'].last()
+    vol_rank = data['volu_hi_low_pct_rank'].last()
 
     # #trend over the all lookback period
     # trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
